package SPVM::DBI;

our $VERSION = "0.001";

1;

=encoding utf8

=head1 Name

SPVM::DBI - DataBase Interface for SPVM (PRE-ALPHA)

=head1 Description

L<SPVM::DBI> is a database interface for the SPVM programming language.

B<WARNING: THIS MODULE IS UNDER HEAVY DEVELOPMENT AND IS NOT YET FUNCTIONAL.>

This is a pre-alpha release. The following points should be noted:

=over 2

=item * This module does not work at all at this stage.

=item * No tests have been written yet.

=item * The public API is not even decided, so everything is private and subject to total change.

=item * DO NOT USE this module. It is only a placeholder for future development.

=back

=head1 Usage

    # No usage available yet.

=head1 Details

None.

=head1 Super Class

L<AnyObject|SPVM::AnyObject>

=head1 Interfaces

None.

=head1 Enumerations

None.

=head1 Fields

None.

=head1 Class Methods

None.

=head1 Instance Methods

None.

=head1 Well Known Child Classes

None.

=head1 See Also

L<DBI>

=head1 Repository

L<https://github.com/yuki-kimoto/SPVM-DBI>

=head1 Author

Yuki Kimoto C<kimoto.yuki@gmail.com>

=head1 Copyright & License

Copyright (c) 2026 Yuki Kimoto

MIT License

=cut
